cmd

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 19, 2026 License: MIT Imports: 17 Imported by: 0

Documentation

Index

Constants

const (
	ExitSuccess  = 0
	ExitError    = 1
	ExitUsage    = 2
	ExitAuth     = 3
	ExitNotFound = 4
	ExitConflict = 5
)

Variables

This section is empty.

Functions

func ExitCodeFromError

func ExitCodeFromError(err error) int

ExitCodeFromError maps an error to a structured exit code.

func HTTPStatusToExitCode

func HTTPStatusToExitCode(status int) int

HTTPStatusToExitCode maps HTTP status codes to exit codes. 4xx -> 10-59, 5xx -> 60-99.

func RootCommand

func RootCommand(version string) *ffcli.Command

RootCommand constructs the root CLI command with all subcommands.

func RootUsageFunc

func RootUsageFunc(c *ffcli.Command) string

RootUsageFunc renders grouped help for the root gplay command.

func Run

func Run(args []string, versionInfo string) int

Run is the main entry point. It returns an exit code.

Types

This section is empty.

Jump to