package
Version:
v0.8.1
Opens a new window with list of versions in this module.
Published: Aug 6, 2026
License: MIT
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
const (
Scope = "https://www.googleapis.com/auth/checks"
)
ResolveAccount returns the Checks account ID from flag, env, or config.
type Service struct {
API *checks.Service
Cfg *config.Config
}
Service wraps the Checks API service and config.
NewService creates an authenticated Checks API service.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.