errors

package
v0.5.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 29, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Package errors implements the `gplay vitals errors` command group for searching error issues and individual error reports via the Google Play Developer Reporting API.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ErrorsCommand

func ErrorsCommand() *ffcli.Command

ErrorsCommand returns the errors command group.

func IssuesCommand

func IssuesCommand() *ffcli.Command

IssuesCommand returns the `gplay vitals errors issues` subcommand.

func ReportsCommand

func ReportsCommand() *ffcli.Command

ReportsCommand returns the `gplay vitals errors reports` subcommand.

Types

This section is empty.

Jump to