Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FormatStderr ¶
FormatStderr returns a formatted error string for stderr output.
Types ¶
type ClassifiedError ¶
ClassifiedError holds a classified error with an actionable hint.
func Classify ¶
func Classify(err error) *ClassifiedError
Classify auto-detects the error category and adds an actionable hint.
func (*ClassifiedError) Error ¶
func (c *ClassifiedError) Error() string
func (*ClassifiedError) Unwrap ¶
func (c *ClassifiedError) Unwrap() error
Click to show internal directories.
Click to hide internal directories.