Documentation
¶
Overview ¶
Package errors implements the `gplay vitals errors` command group for searching error issues and individual error reports via the Google Play Developer Reporting API.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ErrorsCommand ¶
ErrorsCommand returns the errors command group.
func IssuesCommand ¶
IssuesCommand returns the `gplay vitals errors issues` subcommand.
func ReportsCommand ¶
ReportsCommand returns the `gplay vitals errors reports` subcommand.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.