Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SecureOpen ¶
SecureOpen opens a file after verifying it resolves within one of the allowedDirs. It cleans the path, resolves symlinks, and checks the resolved path is within bounds.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.